Decoder

Struct Decoder 

pub struct Decoder<R> {
    pub r: R,
    /* private fields */
}
This structure is used to decode a stream of BWT blocks. This wraps an internal reader which is read from when this decoder’s read method is called.

Fields

r: R

The internally wrapped reader. This is exposed so it may be moved out of. Note that if data is read from the reader while decoding is in progress the output stream will get corrupted.

Implementations

Source

impl<R: Read> Decoder<R>

pub fn new(r: R, extra_mem: bool) -> Decoder<R>

Creates a new decoder which will read data from the given stream. The inner stream can be re-acquired by moving out of the r field of this structure. ‘extra_mem’ switch allows allocating extra N words of memory for better performance

pub fn reset(&mut self)

Resets this decoder back to its initial state. Note that the underlying stream is not seeked on or has any alterations performed on it.