pub struct Decoder<R> {
pub r: R,
/* private fields */
}Expand description
This structure is used to decode a stream of BWT blocks. This wraps an internal reader which is read from when this decoder’s read method is called.
Fields
r: RThe internally wrapped reader. This is exposed so it may be moved out of. Note that if data is read from the reader while decoding is in progress the output stream will get corrupted.
Implementations
Sourceimpl<R: Read> Decoder<R>
impl<R: Read> Decoder<R>